==> django-bom-1.11.tar.gz: django-bom-1.11/bom/octopart_parts_match.py <==
import json
import urllib
import os

from .models import Part, Seller, SellerPart
from django.conf import settings

def match_part(part, organization):
    # returns [{ seller: seller, }]
    # OCTOPART_API_KEY = os.environ.get('OCTOPART_API_KEY')
    OCTOPART_API_KEY = settings.BOM_CONFIG['octopart_api_key']

    if not OCTOPART_API_KEY:
        raise ValueError('No API key found on server. Contact administrator for help.')

    query = [{'mpn': part.manufacturer_part_number}]

    url = 'https://octopart.com/api/v3/parts/match?queries=%s' \
        % urllib.quote(json.dumps(query))
    url += '&apikey=' + OCTOPART_API_KEY

    try:
        data = urllib.urlopen(url).read()
    except Exception as e:
        raise

    response = json.loads(data)

    # need for each part: digi-key, mouser prices, moqs, lead times
    DIGI_KEY_SELLER_ID = '459'
    MOUSER_SELLER_ID = '2401'

    seller_parts = []

    # print mpn's
    for result in response['results']:
        for item in result['items']:
            for offer in item['offers']:
                if (offer['seller']['id'] == DIGI_KEY_SELLER_ID or
                        offer['seller']['id'] == MOUSER_SELLER_ID):
                    seller_name = offer['seller']['name']
                    seller, created = Seller.objects.get_or_create(
                        name__iexact=seller_name, 
                        organization=organization, 
                        defaults={'name': seller_name})
                    ltd = offer['factory_lead_days']
                    if 'USD' in offer['prices']:
                        for price in offer['prices']['USD']:
                            try:
                                moq = price[0]
                                price = price[1]
                                seller_parts.append(
                                    SellerPart(
                                        seller=seller,
                                        part=part,
                                        minimum_order_quantity=moq,
                                        unit_cost=price,
                                        lead_time_days=ltd,
                                        data_source='octopart'))
                            except Exception as e:
                                raise

    return seller_parts

==> django-bom-1.13.tar.gz: django-bom-1.13/bom/octopart_parts_match.py <==
import json
import urllib
import os

from .models import Part, Seller, SellerPart
from django.conf import settings

def match_part(part, organization):
    # returns [{ seller: seller, }]
    # OCTOPART_API_KEY = os.environ.get('OCTOPART_API_KEY')
    OCTOPART_API_KEY = settings.BOM_CONFIG['octopart_api_key']

    if not OCTOPART_API_KEY:
        raise ValueError('No API key found on server. Contact administrator for help.')

    query = [{'mpn': part.manufacturer_part_number}]

    url = 'https://octopart.com/api/v3/parts/match?queries=%s' \
        % urllib.parse.quote(json.dumps(query))
    url += '&apikey=' + OCTOPART_API_KEY

    try:
        data = urllib.request.urlopen(url).read()
    except Exception as e:
        raise

    response = json.loads(data)

    # need for each part: digi-key, mouser prices, moqs, lead times
    DIGI_KEY_SELLER_ID = '459'
    MOUSER_SELLER_ID = '2401'

    seller_parts = []

    # print mpn's
    for result in response['results']:
        for item in result['items']:
            for offer in item['offers']:
                if (offer['seller']['id'] == DIGI_KEY_SELLER_ID or
                        offer['seller']['id'] == MOUSER_SELLER_ID):
                    seller_name = offer['seller']['name']
                    seller, created = Seller.objects.get_or_create(
                        name__iexact=seller_name, 
                        organization=organization, 
                        defaults={'name': seller_name})
                    ltd = offer['factory_lead_days']
                    if 'USD' in offer['prices']:
                        for price in offer['prices']['USD']:
                            try:
                                moq = price[0]
                                price = price[1]
                                seller_parts.append(
                                    SellerPart(
                                        seller=seller,
                                        part=part,
                                        minimum_order_quantity=moq,
                                        unit_cost=price,
                                        lead_time_days=ltd,
                                        data_source='octopart'))
                            except Exception as e:
                                raise

    return seller_parts
